@@ -31,6 +31,10 @@
 #include "logging.h"
 #include "x11-color.h"
 
+#ifdef BUILD_X11
+std::unordered_map<Colour, unsigned long, Colour::Hash> Colour::x11_pixels;
+#endif /* BUILD_X11 */
+
 static int hex_nibble_value(char c) {
   if (c >= '0' && c <= '9') {
     return c - '0';
@@ -51,7 +55,7 @@ Colour Colour::from_argb32(uint32_t argb) {
   return out;
 }
 
-Colour error_colour { 0xff, 0x00, 0x00, 0xff };
+Colour error_colour{0xff, 0x00, 0x00, 0xff};
 
 Colour parse_color(const char *name) {
   unsigned short r, g, b;
