@@ -352,10 +352,7 @@ void print_no_update(struct text_object *obj, char *p,
 
 #ifdef BUILD_GUI
 void scan_loadgraph_arg(struct text_object *obj, const char *arg) {
-  char *buf = nullptr;
-
-  buf = scan_graph(obj, arg, 0);
-  free_and_zero(buf);
+  scan_graph(obj, arg, 0);
 }
 
 double loadgraphval(struct text_object *obj) {
