@@ -172,8 +172,8 @@ void print_diskio_write(struct text_object *obj, char *p,
 
 #ifdef BUILD_GUI
 void parse_diskiograph_arg(struct text_object *obj, const char *arg) {
-  char *buf = nullptr;
-  buf = scan_graph(obj, arg, 0);
+  auto [buf, skip] = scan_command(arg);
+  scan_graph(obj, arg + skip, 0);
 
   obj->data.opaque = prepare_diskio_stat(dev_name(buf));
   free_and_zero(buf);
