@@ -26,8 +26,8 @@
 
 #include <config.h>
 
-#include "conky.h"
 #include "colours.h"
+#include "conky.h"
 #include "display-ncurses.hh"
 #include "gui.h"
 #include "nc.h"
@@ -40,7 +40,7 @@
 #endif
 
 #ifdef BUILD_NCURSES
-extern WINDOW *ncurses_window;
+extern WINDOW* ncurses_window;
 #endif
 
 namespace conky {
@@ -65,39 +65,38 @@ extern void init_ncurses_output() {}
 #define COLORS_BUILTIN 8
 
 Colour ncurses_colors[COLORS_BUILTIN + COLORS_CUSTOM] = {
-    {0x00, 0x00, 0x00, 0xff}, // BLACK
-    {0xff, 0x00, 0x00, 0xff}, // RED
-    {0x00, 0xff, 0x00, 0xff}, // GREEN
-    {0xff, 0xff, 0x00, 0xff}, // YELLOW
-    {0x00, 0x00, 0xff, 0xff}, // BLUE
-    {0xff, 0x00, 0xff, 0xff}, // MAGENTA
-    {0x00, 0xff, 0xff, 0xff}, // CYAN
-    {0xff, 0xff, 0xff, 0xff}, // WHITE
+    {0x00, 0x00, 0x00, 0xff},  // BLACK
+    {0xff, 0x00, 0x00, 0xff},  // RED
+    {0x00, 0xff, 0x00, 0xff},  // GREEN
+    {0xff, 0xff, 0x00, 0xff},  // YELLOW
+    {0x00, 0x00, 0xff, 0xff},  // BLUE
+    {0xff, 0x00, 0xff, 0xff},  // MAGENTA
+    {0x00, 0xff, 0xff, 0xff},  // CYAN
+    {0xff, 0xff, 0xff, 0xff},  // WHITE
 };
 
-  // Find the nearest ncurses color.
-  int to_ncurses(const Colour& c) {
-    int mindiff = INT_MAX;
-    int best_nccolor = 0;
-    for (int nccolor = 0; nccolor < COLORS_BUILTIN + COLORS_CUSTOM; nccolor++) {
-      const Colour& other = ncurses_colors[nccolor];
-      int diff = abs(c.red - other.red) +
-                 abs(c.green - other.green) +
-                 abs(c.blue - other.blue);
+// Find the nearest ncurses color.
+int to_ncurses(const Colour& c) {
+  int mindiff = INT_MAX;
+  int best_nccolor = 0;
+  for (int nccolor = 0; nccolor < COLORS_BUILTIN + COLORS_CUSTOM; nccolor++) {
+    const Colour& other = ncurses_colors[nccolor];
+    int diff = abs(c.red - other.red) + abs(c.green - other.green) +
+               abs(c.blue - other.blue);
 
-      if (diff < mindiff) {
-        mindiff = diff;
-        best_nccolor = nccolor;
-      }
+    if (diff < mindiff) {
+      mindiff = diff;
+      best_nccolor = nccolor;
     }
-    return best_nccolor;
   }
+  return best_nccolor;
+}
 
 Colour from_ncurses(int nccolor) {
-    if (nccolor >= 0 && nccolor < COLORS_BUILTIN + COLORS_CUSTOM) {
-        return ncurses_colors[nccolor];
-    }
-    return error_colour;
+  if (nccolor >= 0 && nccolor < COLORS_BUILTIN + COLORS_CUSTOM) {
+    return ncurses_colors[nccolor];
+  }
+  return error_colour;
 }
 
 display_output_ncurses::display_output_ncurses()
@@ -114,9 +113,10 @@ bool display_output_ncurses::detect() {
 }
 
 bool display_output_ncurses::initialize() {
-  for(int i = 0; i < COLORS_CUSTOM; i++) {
+  for (int i = 0; i < COLORS_CUSTOM; i++) {
     Colour c = color[i].get(*state);
-    init_color(COLORS_BUILTIN + i, (1000*c.red)/255, (1000*c.green)/255, (1000*c.blue)/255);
+    init_color(COLORS_BUILTIN + i, (1000 * c.red) / 255, (1000 * c.green) / 255,
+               (1000 * c.blue) / 255);
     ncurses_colors[COLORS_BUILTIN + i] = c;
   }
 
@@ -139,7 +139,7 @@ void display_output_ncurses::begin_draw_text() {
 
 void display_output_ncurses::end_draw_text() {}
 
-void display_output_ncurses::draw_string(const char *s, int) {
+void display_output_ncurses::draw_string(const char* s, int) {
   printw("%s", s);
 }
 
