@@ -34,6 +34,9 @@ extern "C" {
 
 #ifdef BUILD_X11
 #include "x11.h"
+#ifdef BUILD_MOUSE_EVENTS
+#include "mouse-events.h"
+#endif /* BUILD_MOUSE_EVENTS */
 #endif /* BUILD_X11 */
 
 #define LUAPREFIX "conky_"
@@ -46,15 +49,24 @@ void llua_inotify_query(int wd, int mask);
 void llua_startup_hook(void);
 void llua_shutdown_hook(void);
 
-#ifdef BUILD_X11
+#ifdef BUILD_GUI
 void llua_draw_pre_hook(void);
 void llua_draw_post_hook(void);
 
+#ifdef BUILD_MOUSE_EVENTS
+/**
+  Takes a mouse_event as argument.
+  Returns true if event was properly consumed, false otherwise.
+ */
+template <typename EventT>
+bool llua_mouse_hook(const EventT &ev);
+#endif /* BUILD_MOUSE_EVENTS */
+
 void llua_setup_window_table(int text_start_x, int text_start_y, int text_width,
                              int text_height);
 void llua_update_window_table(int text_start_x, int text_start_y,
                               int text_width, int text_height);
-#endif /* BUILD_X11 */
+#endif /* BUILD_GUI */
 
 void llua_setup_info(struct information *i, double u_interval);
 void llua_update_info(struct information *i, double u_interval);
