@@ -333,8 +333,8 @@ void print_v6addrs(struct text_object *obj, char *p, unsigned int p_max_size) {
 void parse_net_stat_graph_arg(struct text_object *obj, const char *arg,
                               void *free_at_crash) {
   /* scan arguments and get interface name back */
-  char *buf = nullptr;
-  buf = scan_graph(obj, arg, 0);
+  auto [buf, skip] = scan_command(arg);
+  scan_graph(obj, arg + skip, 0);
 
   // default to DEFAULTNETDEV
   if (buf != nullptr) {
